# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.1] - - 2024-01-29

### Added

    - py.typed
    - Changelog
  
## [0.1.0] - 2024-01-27

### Added

    - First public release
  